<?php
/**
 * WC_Boxpack_Item class file.
 *
 * @package WC_Shipping_Royalmail
 */

/**
 * WC_Boxpack_Item class.
 */
class WC_Boxpack_Item {

	/**
	 * Weight of the item itself.
	 *
	 * @var float
	 */
	public $weight;

	/**
	 * Height of the item itself.
	 *
	 * @var float
	 */
	public $height;

	/**
	 * Width of the item itself.
	 *
	 * @var float
	 */
	public $width;

	/**
	 * Length of the item itself.
	 *
	 * @var float
	 */
	public $length;

	/**
	 * Volume of the item itself.
	 *
	 * @var float
	 */
	public $volume;

	/**
	 * Value of the item itself.
	 *
	 * @var mixed
	 */
	public $value;

	/**
	 * Meta of the item itself.
	 *
	 * @var mixed
	 */
	public $meta;

	/**
	 * Class constructor.
	 *
	 * @param float $length Length of the item.
	 * @param float $width Width of the item.
	 * @param float $height Height of the item.
	 * @param float $weight Weight of the item.
	 * @param mixed $value Value of the item.
	 * @param mixed $meta Meta of the item.
	 *
	 * @return void
	 */
	public function __construct( $length, $width, $height, $weight, $value = '', $meta = array() ) {
		$dimensions = array( $length, $width, $height );

		sort( $dimensions );

		$this->length = floatval( $dimensions[2] );
		$this->width  = floatval( $dimensions[1] );
		$this->height = floatval( $dimensions[0] );

		$this->volume = floatval( $width * $height * $length );
		$this->weight = floatval( $weight );
		$this->value  = $value;
		$this->meta   = $meta;
	}

	/**
	 * Get item's volume.
	 *
	 * @return float
	 */
	public function get_volume() {
		return $this->volume;
	}

	/**
	 * Get item's height.
	 *
	 * @return float
	 */
	public function get_height() {
		return $this->height;
	}

	/**
	 * Get item's width.
	 *
	 * @return float
	 */
	public function get_width() {
		return $this->width;
	}

	/**
	 * Get item's length.
	 *
	 * @return float
	 */
	public function get_length() {
		return $this->length;
	}

	/**
	 * Get item's weight.
	 *
	 * @return float
	 */
	public function get_weight() {
		return $this->weight;
	}

	/**
	 * Get item value.
	 *
	 * @return float
	 */
	public function get_value() {
		return $this->value;
	}

	/**
	 * Get meta from the item.
	 *
	 * @param string $key Meta key.
	 *
	 * @return mixed.
	 */
	public function get_meta( $key = '' ) {
		if ( $key ) {
			if ( isset( $this->meta[ $key ] ) ) {
				return $this->meta[ $key ];
			} else {
				return null;
			}
		} else {
			return array_filter( (array) $this->meta );
		}
	}
}
