<?php
/**
 * Plugin Name: WooCommerce Royal Mail
 * Plugin URI: https://woocommerce.com/products/royal-mail/
 * Description: Offer Royal Mail shipping rates automatically to your customers. Prices according to <a href="https://www.royalmail.com/sites/royalmail.com/files/2024-03/our-prices-april-2024-v1-ta.pdf">the 2024 price guide</a>.
 * Version: 3.2.4
 * Author: WooCommerce
 * Author URI: https://woocommerce.com/
 * Text Domain: woocommerce-shipping-royalmail
 * Domain Path: /languages
 * Copyright: © 2024 WooCommerce
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * WC tested up to: 8.8
 * WC requires at least: 8.6
 * Tested up to: 6.5
 * Requires Plugins: woocommerce
 *
 * Woo: 182719:03839cca1a16c4488fcb669aeb91a056
 *
 * @package WC_RoyalMail
 */

if ( ! defined( 'WOOCOMMERCE_SHIPPING_ROYALMAIL_FILE' ) ) {
	define( 'WOOCOMMERCE_SHIPPING_ROYALMAIL_FILE', __FILE__ );
}

if ( ! defined( 'WOOCOMMERCE_SHIPPING_ROYALMAIL_ABSPATH' ) ) {
	define( 'WOOCOMMERCE_SHIPPING_ROYALMAIL_ABSPATH', trailingslashit( __DIR__ ) );
}

/**
 * WooCommerce fallback notice.
 *
 * @since 2.5.24
 * @return void
 */
function woocommerce_shipping_royalmail_missing_wc_notice() {
	/* translators: %s WC download URL link. */
	echo '<div class="error"><p><strong>' . sprintf( esc_html__( 'Royalmail requires WooCommerce to be installed and active. You can download %s here.', 'woocommerce-shipping-royalmail' ), '<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>' ) . '</strong></p></div>';
}

/**
 * Only load the plugin if WooCommerce is activated
 */
if ( ! class_exists( 'WC_RoyalMail' ) ) :
	define( 'WOOCOMMERCE_SHIPPING_ROYALMAIL_VERSION', '3.2.4' ); // WRCS: DEFINED_VERSION.

	require_once WOOCOMMERCE_SHIPPING_ROYALMAIL_ABSPATH . 'includes/class-wc-royalmail.php';
endif;

add_action( 'plugins_loaded', 'woocommerce_shipping_royalmail_init' );

// Subscribe to automated translations.
add_filter( 'woocommerce_translations_updates_for_' . basename( WOOCOMMERCE_SHIPPING_ROYALMAIL_FILE, '.php' ), '__return_true' );

/**
 * Initializes extension.
 *
 * @since 2.5.24
 * @return void
 */
function woocommerce_shipping_royalmail_init() {
	load_plugin_textdomain( 'woocommerce-shipping-royalmail', false, plugin_basename( dirname( WOOCOMMERCE_SHIPPING_ROYALMAIL_FILE ) ) . '/languages' );

	if ( ! class_exists( 'WooCommerce' ) ) {
		add_action( 'admin_notices', 'woocommerce_shipping_royalmail_missing_wc_notice' );
		return;
	}

	new WC_RoyalMail();
}
